"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require("react");

var _react2 = _interopRequireDefault(_react);

var _server = require("react-dom/server");

var _server2 = _interopRequireDefault(_server);

var _typography = require("typography");

var _typography2 = _interopRequireDefault(_typography);

var _reactTypography = require("react-typography");

var _lodash = require("lodash");

var _lodash2 = _interopRequireDefault(_lodash);

var _themes = require("../themes");

var _themes2 = _interopRequireDefault(_themes);

var _NumberEditor = require("./NumberEditor");

var _NumberEditor2 = _interopRequireDefault(_NumberEditor);

var _grayPercentage = require("gray-percentage");

var _grayPercentage2 = _interopRequireDefault(_grayPercentage);

var _GoogleFonts = require("./GoogleFonts");

var _GoogleFonts2 = _interopRequireDefault(_GoogleFonts);

var _Select = require("./Select");

var _Select2 = _interopRequireDefault(_Select);

var _SectionTool = require("./SectionTool");

var _SectionTool2 = _interopRequireDefault(_SectionTool);

var _msToRatio = require("./msToRatio");

var _msToRatio2 = _interopRequireDefault(_msToRatio);

var _ModularScaleTool = require("./ModularScaleTool");

var _ModularScaleTool2 = _interopRequireDefault(_ModularScaleTool);

var _parseUnit = require("parse-unit");

var _parseUnit2 = _interopRequireDefault(_parseUnit);

var _FontSelectTool = require("./FontSelectTool");

var _FontSelectTool2 = _interopRequireDefault(_FontSelectTool);

var _FontWeightTool = require("./FontWeightTool");

var _FontWeightTool2 = _interopRequireDefault(_FontWeightTool);

var _filteredGoogleFontList = require("../filteredGoogleFontList.json");

var _filteredGoogleFontList2 = _interopRequireDefault(_filteredGoogleFontList);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var requireThemes = require.context("../../", true, /^\.\/typography-theme.*\/src\/index.js$/);
var themeRegistry = [];
_lodash2.default.each(_themes2.default, function (theme) {
  themeRegistry.push({
    name: theme.name,
    title: theme.title,
    module: requireThemes(theme.requireStr)
  });
});

// Add default theme
themeRegistry.unshift({
  name: "default",
  title: "Default",
  module: {}
});

var toolTypography = new _typography2.default({ includeNormalize: false });

var Section = function Section(_ref) {
  var children = _ref.children;
  return _react2.default.createElement(
    "div",
    {
      style: {
        clear: "both",
        paddingBottom: 3.75,
        paddingLeft: 7.5,
        paddingRight: 7.5
      }
    },
    children
  );
};
var SectionRow = function SectionRow(_ref2) {
  var children = _ref2.children;
  return _react2.default.createElement(
    "div",
    {
      style: {
        marginBottom: 3.75,
        overflow: "hidden"
      }
    },
    children
  );
};

var SectionHeader = function SectionHeader(_ref3) {
  var children = _ref3.children;
  return _react2.default.createElement(
    "div",
    {
      style: {
        background: (0, _grayPercentage2.default)(17),
        borderBottom: "1px solid",
        borderColor: (0, _grayPercentage2.default)(50, 0, true),
        fontSize: 13,
        paddingLeft: 7.5,
        marginLeft: -7.5,
        marginRight: -7.5,
        marginBottom: 3.75
      }
    },
    children
  );
};

var DesignTool = function (_React$Component) {
  _inherits(DesignTool, _React$Component);

  function DesignTool(props) {
    _classCallCheck(this, DesignTool);

    var _this = _possibleConstructorReturn(this, (DesignTool.__proto__ || Object.getPrototypeOf(DesignTool)).call(this));

    _this.googleFonts = JSON.stringify(props.typography.options.googleFonts);
    var options = new _typography2.default(props.typography.options).options;
    var bodyFamily = _lodash2.default.find(_filteredGoogleFontList2.default, function (font) {
      return font.family === props.typography.options.bodyFontFamily[0];
    });
    var headerFamily = _lodash2.default.find(_filteredGoogleFontList2.default, function (font) {
      return font.family === props.typography.options.headerFontFamily[0];
    });
    if (!bodyFamily) {
      bodyFamily = {};
    }
    if (!headerFamily) {
      headerFamily = {};
    }
    _this.state = {
      selectedTheme: 0,
      options: options,
      bodyFamily: bodyFamily,
      headerFamily: headerFamily
    };
    return _this;
  }

  _createClass(DesignTool, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var options = themeRegistry.map(function (theme, i) {
        return _react2.default.createElement(
          "option",
          { key: i, value: i },
          theme.title
        );
      });

      // Inject active theme.
      if (typeof document !== "undefined") {
        var activeTheme = themeRegistry[this.state.selectedTheme].module;
        // Copy over plugins/overrideThemeStyles
        activeTheme = _extends({}, activeTheme, this.state.options);
        activeTheme.plugins = this.props.typography.options.plugins;
        activeTheme.overrideThemeStyles = this.props.typography.options.overrideThemeStyles;

        var newTypography = new _typography2.default(activeTheme);
        newTypography.injectStyles();

        // If Google Fonts have changed, insert them.
        if (this.googleFonts !== JSON.stringify(newTypography.options.googleFonts)) {
          var googleFonts = _server2.default.renderToStaticMarkup(_react2.default.createFactory(_reactTypography.GoogleFont)({ typography: newTypography }));
          var head = document.getElementsByTagName("head")[0];
          head.insertAdjacentHTML("beforeend", googleFonts);
          this.googleFonts = JSON.stringify(newTypography.options.googleFonts);
        }
      }

      return _react2.default.createElement(
        "div",
        {
          style: {
            fontFamily: toolTypography.options.headerFontFamily,
            fontWeight: 300,
            fontSize: 10,
            lineHeight: 1.5,
            letterSpacing: 0,
            background: "rgba(0,0,0,0.65)",
            color: "rgba(255,255,255,0.95)",
            position: "fixed",
            top: 0,
            right: 0,
            WebkitFontSmoothing: "auto"
          }
        },
        _react2.default.createElement(
          Section,
          null,
          _react2.default.createElement(
            "div",
            {
              style: {
                color: "rgba(255,255,255,0.95)",
                fontFamily: toolTypography.options.headerFontFamily,
                fontSize: 15,
                fontWeight: 300,
                marginBottom: 0,
                marginTop: 10
              }
            },
            "Typography.js"
          ),
          _react2.default.createElement(
            SectionRow,
            null,
            _react2.default.createElement(
              "div",
              {
                style: {
                  fontSize: 10,
                  lineHeight: "15px",
                  marginTop: 7.5
                }
              },
              "Pick theme"
            ),
            _react2.default.createElement(_Select2.default, {
              options: themeRegistry.map(function (theme) {
                return theme.title;
              }),
              value: this.state.selectedTheme,
              style: {
                width: "100%"
              },
              onChange: function onChange(value) {
                var newTheme = new _typography2.default(themeRegistry[value].module);
                var newBodyFamily = _lodash2.default.find(_filteredGoogleFontList2.default, function (font) {
                  return font.family === newTheme.options.bodyFontFamily[0];
                });
                var newHeaderFamily = _lodash2.default.find(_filteredGoogleFontList2.default, function (font) {
                  return font.family === newTheme.options.headerFontFamily[0];
                });
                if (!newBodyFamily) {
                  newBodyFamily = {};
                }
                if (!newHeaderFamily) {
                  newHeaderFamily = {};
                }
                _this2.setState({
                  selectedTheme: parseInt(value, 10),
                  options: newTheme.options,
                  bodyFamily: newBodyFamily,
                  headerFamily: newHeaderFamily
                });
              }
            })
          )
        ),
        _react2.default.createElement(
          Section,
          null,
          _react2.default.createElement(
            SectionHeader,
            null,
            "Base sizes"
          ),
          _react2.default.createElement(
            SectionRow,
            null,
            _react2.default.createElement(
              _SectionTool2.default,
              { title: "Font size" },
              _react2.default.createElement(_NumberEditor2.default, {
                unit: "px",
                value: (0, _parseUnit2.default)(this.state.options.baseFontSize)[0],
                min: 9,
                max: 100,
                step: 0.25,
                decimals: 2,
                onValueChange: function onValueChange(value) {
                  var newOptions = _extends({}, _this2.state.options);
                  newOptions.baseFontSize = value + "px";
                  _this2.setState({ options: newOptions });
                }
              })
            ),
            _react2.default.createElement(
              _SectionTool2.default,
              { title: "Line Height" },
              _react2.default.createElement(_NumberEditor2.default, {
                unit: "number",
                value: this.state.options.baseLineHeight,
                min: 1,
                max: 2.5,
                step: 0.01,
                decimals: 2,
                onValueChange: function onValueChange(value) {
                  var newOptions = _extends({}, _this2.state.options);
                  var fontsize = (0, _parseUnit2.default)(_this2.state.options.baseFontSize)[0];
                  newOptions.baseLineHeight = value;
                  _this2.setState({
                    options: newOptions
                  });
                }
              })
            )
          ),
          _react2.default.createElement(
            SectionRow,
            null,
            _react2.default.createElement(_ModularScaleTool2.default, {
              key: "scale",
              scaleRatio: this.state.options.scaleRatio,
              onChange: function onChange(newScale) {
                var newOptions = _extends({}, _this2.state.options);
                newOptions.scaleRatio = newScale;
                _this2.setState({ options: newOptions });
              }
            }),
            _react2.default.createElement(
              _SectionTool2.default,
              { title: "Paragraph Spacing" },
              _react2.default.createElement(_NumberEditor2.default, {
                unit: "rhythm",
                value: this.state.options.blockMarginBottom,
                min: 0.25,
                max: 3,
                step: 0.1,
                decimals: 2,
                onValueChange: function onValueChange(value) {
                  var options = _this2.state.options;
                  options.blockMarginBottom = parseFloat(value);
                  _this2.setState({ options: options });
                }
              })
            )
          )
        ),
        _react2.default.createElement(
          Section,
          null,
          _react2.default.createElement(
            SectionHeader,
            null,
            "Headers"
          ),
          _react2.default.createElement(
            SectionRow,
            null,
            _react2.default.createElement(
              "div",
              null,
              "Typeface"
            ),
            _react2.default.createElement(_FontSelectTool2.default, {
              type: "header",
              options: this.state.options,
              onChange: function onChange(options, headerFamily) {
                _this2.setState({ options: options, headerFamily: headerFamily });
              }
            })
          ),
          _react2.default.createElement(
            SectionRow,
            null,
            _react2.default.createElement(
              _SectionTool2.default,
              { title: "Weight" },
              _react2.default.createElement(_FontWeightTool2.default, {
                type: "header",
                family: this.state.headerFamily,
                weight: this.state.options.headerWeight,
                options: this.state.options,
                onChange: function onChange(newOptions) {
                  return _this2.setState({ options: newOptions });
                }
              })
            ),
            _react2.default.createElement(
              _SectionTool2.default,
              { title: "Gray value" },
              _react2.default.createElement(_NumberEditor2.default, {
                unit: "%",
                value: this.state.options.headerGray,
                min: 0,
                max: 100,
                step: 1,
                decimals: 0,
                onValueChange: function onValueChange(value) {
                  var options = _this2.state.options;
                  options.headerGray = value;
                  _this2.setState({ options: options });
                }
              })
            )
          )
        ),
        _react2.default.createElement(
          Section,
          null,
          _react2.default.createElement(
            SectionHeader,
            null,
            "Body"
          ),
          _react2.default.createElement(
            SectionRow,
            null,
            _react2.default.createElement(
              "div",
              null,
              "Typeface"
            ),
            _react2.default.createElement(_FontSelectTool2.default, {
              type: "body",
              options: this.state.options,
              onChange: function onChange(options, bodyFamily) {
                _this2.setState({ options: options, bodyFamily: bodyFamily });
              }
            })
          ),
          _react2.default.createElement(
            SectionRow,
            null,
            _react2.default.createElement(
              _SectionTool2.default,
              { title: "Body Weight" },
              _react2.default.createElement(_FontWeightTool2.default, {
                type: "body",
                family: this.state.bodyFamily,
                weight: this.state.options.bodyWeight,
                options: this.state.options,
                onChange: function onChange(newOptions) {
                  return _this2.setState({ options: newOptions });
                }
              })
            ),
            _react2.default.createElement(
              _SectionTool2.default,
              { title: "Bold Weight" },
              _react2.default.createElement(_FontWeightTool2.default, {
                type: "bold",
                family: this.state.bodyFamily,
                weight: this.state.options.boldWeight,
                options: this.state.options,
                onChange: function onChange(newOptions) {
                  return _this2.setState({ options: newOptions });
                }
              })
            )
          ),
          _react2.default.createElement(
            SectionRow,
            null,
            _react2.default.createElement(
              _SectionTool2.default,
              { title: "Body gray" },
              _react2.default.createElement(_NumberEditor2.default, {
                unit: "%",
                value: this.state.options.bodyGray,
                min: 0,
                max: 100,
                step: 1,
                decimals: 0,
                onValueChange: function onValueChange(value) {
                  var options = _this2.state.options;
                  options.bodyGray = value;
                  _this2.setState({ options: options });
                }
              })
            )
          )
        )
      );
    }
  }]);

  return DesignTool;
}(_react2.default.Component);

exports.default = DesignTool;
module.exports = exports["default"];