"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require("react");

var _react2 = _interopRequireDefault(_react);

var _reactSelect = require("react-select");

var _reactSelect2 = _interopRequireDefault(_reactSelect);

var _filteredGoogleFontList = require("../filteredGoogleFontList.json");

var _filteredGoogleFontList2 = _interopRequireDefault(_filteredGoogleFontList);

var _aphrodite = require("aphrodite");

var _lodash = require("lodash");

var _lodash2 = _interopRequireDefault(_lodash);

var _reactAutosuggest = require("react-autosuggest");

var _reactAutosuggest2 = _interopRequireDefault(_reactAutosuggest);

var _grayPercentage = require("gray-percentage");

var _grayPercentage2 = _interopRequireDefault(_grayPercentage);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var styles = _aphrodite.StyleSheet.create({
  input: {
    background: "url(\"data:image/svg+xml;utf8,<svg version='1.1' xmlns='http://www.w3.org/2000/svg' xmlns:xlink='http://www.w3.org/1999/xlink' width='18' height='18' viewBox='0 0 24 24'><path fill='rgb(153, 153, 153)' d='M7.406 7.828l4.594 4.594 4.594-4.594 1.406 1.406-6 6-6-6z'></path></svg>\")",
    backgroundColor: (0, _grayPercentage2.default)(20),
    backgroundPosition: "100% 50%",
    backgroundRepeat: "no-repeat",
    border: "1px solid",
    borderColor: (0, _grayPercentage2.default)(50, 0, true),
    borderRadius: 3,
    color: (0, _grayPercentage2.default)(90, 0, true),
    fontSize: 12,
    width: "100%",
    padding: "2px 8px",
    marginBottom: 3.75
  },
  suggestionsContainer: {
    background: (0, _grayPercentage2.default)(20),
    border: "1px solid",
    borderColor: (0, _grayPercentage2.default)(50, 0, true),
    borderRadius: 3,
    color: (0, _grayPercentage2.default)(90, 0, true),
    fontSize: 12,
    padding: 0,
    margin: 0,
    listStyle: "none",
    position: "absolute",
    zIndex: 1,
    overflow: "hidden",
    overflowY: "scroll",
    maxHeight: "500px",
    width: "93%"
  },
  suggestion: {
    color: (0, _grayPercentage2.default)(90, 0, true),
    padding: "3.75px 7px",
    margin: 0
  },
  suggestionFocused: {
    background: (0, _grayPercentage2.default)(35, 0, true),
    color: (0, _grayPercentage2.default)(95, 0, true)
  }
});

var options = _filteredGoogleFontList2.default.map(function (font) {
  return {
    name: font.family
  };
});

var pickBoldStyle = function pickBoldStyle(name) {
  var family = _lodash2.default.find(_filteredGoogleFontList2.default, function (font) {
    return font.family === name;
  });

  // Pick heaviest weight that's not an italic.
  var weights = _lodash2.default.map(family.weights, function (weight) {
    if (weight === "regular") {
      return 400;
    } else {
      return parseInt(weight, 10);
    }
  });
  weights = _lodash2.default.filter(_lodash2.default.sortBy(weights), function (weight) {
    return _lodash2.default.isFinite(weight);
  });
  if (_lodash2.default.includes(weights, 700)) {
    return 700;
  } else {
    return _lodash2.default.last(weights);
  }
};

function getSuggestions(value) {
  var inputValue = value.trim().toLowerCase();
  var inputLength = inputValue.length;

  if (inputValue === "") {
    return options;
  }

  return inputLength === 0 ? [] : options.filter(function (option) {
    return _lodash2.default.includes(option.name.toLowerCase(), inputValue);
  });
}

function getSuggestionValue(suggestion) {
  // when suggestion selected, this function tells
  return suggestion.name; // what should be the value of the input
}

function renderSuggestion(suggestion) {
  return _react2.default.createElement(
    "span",
    null,
    suggestion.name
  );
}

var FontSelectTool = function (_React$Component) {
  _inherits(FontSelectTool, _React$Component);

  function FontSelectTool(props) {
    _classCallCheck(this, FontSelectTool);

    var _this = _possibleConstructorReturn(this, (FontSelectTool.__proto__ || Object.getPrototypeOf(FontSelectTool)).call(this));

    var fontFamily = void 0;
    if (props.type === "header") {
      fontFamily = props.options.headerFontFamily[0];
    } else if (props.type === "body") {
      fontFamily = props.options.bodyFontFamily[0];
    }

    _this.state = {
      value: fontFamily,
      suggestions: getSuggestions("")
    };

    _this.onChange = _this.onChange.bind(_this);
    _this.onSuggestionsUpdateRequested = _this.onSuggestionsUpdateRequested.bind(_this);
    return _this;
  }

  _createClass(FontSelectTool, [{
    key: "onChange",
    value: function onChange(event, _ref) {
      var _this2 = this;

      var newValue = _ref.newValue;

      this.setState({
        value: newValue
      });
      var newOptions = _extends({}, this.props.options);
      var family = _lodash2.default.find(_filteredGoogleFontList2.default, function (font) {
        return font.family === newValue;
      });

      if (family) {
        // Choose weight for choosen header font.
        if (this.props.type === "header") {
          // Set header font family.
          newOptions.headerFontFamily = [newValue, family.category];

          var weight = pickBoldStyle(newValue);

          // Set weight.
          newOptions.headerWeight = weight;

          // Add font to Google Fonts array.
          newOptions.googleFonts.push({
            name: newValue,
            styles: [weight]
          });

          // Filter out old font.
          newOptions.googleFonts = _lodash2.default.filter(newOptions.googleFonts, function (font) {
            return font.name !== _this2.props.options.headerFontFamily[0];
          });
        } else if (this.props.type === "body") {
          // Set body font family.
          newOptions.bodyFontFamily = [newValue, family.category];

          var boldWeight = pickBoldStyle(newValue);

          // Set weights.
          newOptions.bodyWeight = 400;
          newOptions.boldWeight = boldWeight;

          // Add font to Google Fonts array.
          newOptions.googleFonts.push({
            name: newValue,
            styles: ["400", "400i", boldWeight.toString(), boldWeight + "i"]
          });

          // Filter out old font.
          newOptions.googleFonts = _lodash2.default.filter(newOptions.googleFonts, function (font) {
            return font.name !== _this2.props.options.bodyFontFamily[0];
          });
        }

        this.props.onChange(newOptions, family);
      }
    }
  }, {
    key: "onSuggestionsUpdateRequested",
    value: function onSuggestionsUpdateRequested(_ref2) {
      var value = _ref2.value;

      this.setState({
        suggestions: getSuggestions(value)
      });
    }
  }, {
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      if (this.props.type === "header") {
        this.setState({
          value: nextProps.options.headerFontFamily[0]
        });
      } else if (this.props.type === "body") {
        this.setState({
          value: nextProps.options.bodyFontFamily[0]
        });
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _state = this.state,
          value = _state.value,
          suggestions = _state.suggestions;

      var inputProps = {
        placeholder: "Type font family",
        value: value,
        onChange: this.onChange
      };

      return _react2.default.createElement(_reactAutosuggest2.default, {
        shouldRenderSuggestions: function shouldRenderSuggestions() {
          return true;
        },
        suggestions: suggestions,
        onSuggestionsUpdateRequested: this.onSuggestionsUpdateRequested,
        getSuggestionValue: getSuggestionValue,
        renderSuggestion: renderSuggestion,
        inputProps: inputProps,
        theme: {
          input: (0, _aphrodite.css)(styles.input),
          suggestionsContainer: (0, _aphrodite.css)(styles.suggestionsContainer),
          suggestion: (0, _aphrodite.css)(styles.suggestion),
          suggestionFocused: (0, _aphrodite.css)(styles.suggestionFocused)
        }
      });
    }
  }]);

  return FontSelectTool;
}(_react2.default.Component);

exports.default = FontSelectTool;
module.exports = exports["default"];